#!/usr/bin/env python3

'''Decrypts the AES key and then uses it to decrypt WUP requests sent by QQ
Browser for Android.
'''

import codecs
import sys

from Crypto.Cipher import AES

import qqrsa

def main():
    if len(sys.argv) != 2:
        sys.stderr.write('Usage: %s HEX_KEY < CRYPTO\n' % sys.argv[0])
        sys.exit(1)
    key_hex = sys.argv[1].strip()
    try:
        key_bytes = codecs.decode(key_hex, 'hex')
    except Exception:
        sys.stderr.write('%s: hex key must be 32 hex chars (16 bytes)\n')
        sys.exit(1)
    if len(key_bytes) != 16:
        sys.stderr.write('%s: hex key must be 32 hex chars (16 bytes)\n')
        sys.exit(1)
    key_bytes_plain = qqrsa.decrypt_string(key_bytes)
    sys.stderr.write('Key: %s\n' % repr(key_bytes_plain)[1:])
    if not key_bytes_plain.isdigit():
        sys.stderr.write('Warning: key not ASCII digits\n')
    cipher = AES.new(key_bytes_plain, AES.MODE_ECB)
    crypto = sys.stdin.buffer.read()
    plain = cipher.decrypt(crypto)
    padding = plain[-1]
    if 0 < padding <= 16 and all(b == padding for b in plain[-padding:]):
        plain = plain[:-padding]
    else:
        sys.stderr.write('Warning: invalid padding\n')
    sys.stdout.buffer.write(plain)

if __name__ == '__main__':
    main()
