'''Support for MTEA crypto padding.'''

import mtea

MODE = mtea.MODE_MCBC
IV = b'\x00' * 8

def encrypt(key, buf):
    m = len(buf)
    padding = (8 - ((m + 10) % 8)) % 8
    n = m + padding + 10
    start = padding + 3
    bufs = b''.join([
        bytes([padding]),
        b'\x00' * (start - 1),
        buf,
        b'\x00' * (n - m - start),
    ])
    cipher = mtea.new(key, mode=MODE, IV=IV)
    crypto = cipher.encrypt(bufs)
    return crypto

def decrypt(key, buf):
    n = len(buf)
    cipher = mtea.new(key, mode=MODE, IV=IV)
    plain = cipher.decrypt(buf)
    padding = plain[0] & 7
    m = n - padding - 10
    start = padding + 3
    return plain[start:start + m]
