#!/usr/bin/env python3

'''Parse WUP requests.'''

import sys

import wupparse

def multi_parse(mv):
    multiparsed = []
    while mv:
        length = int.from_bytes(wupparse.read(mv, 4), 'big')
        if length < 4:
            raise ValueError('length must be >= 4')
        mv = mv[4:]
        parse_mv = wupparse.read(mv, length - 4)
        parsed = wupparse.parse(parse_mv)
        multiparsed.append((length, parsed))
        mv = mv[length - 4:]
    return multiparsed

def main():
    buf = sys.stdin.buffer.read()
    multiparsed = multi_parse(memoryview(buf))
    for length, parsed in multiparsed:
        print('Packet of %d bytes:' % length)
        for elem in parsed:
            wupparse.print_elem(elem)

if __name__ == '__main__':
    main()
